==> eiffelstudio-18.01.10.1424.tar: F_code/C6/ir291.c <==
/*
 * Code for class IRON_PACKAGE_FILE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir291.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_PACKAGE_FILE}.path */
EIF_REFERENCE F332_5012 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {IRON_PACKAGE_FILE}.projects */
EIF_REFERENCE F332_5014 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {IRON_PACKAGE_FILE}.setup_operations */
EIF_REFERENCE F332_5015 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {IRON_PACKAGE_FILE}.exists */
EIF_BOOLEAN F332_5020 (EIF_REFERENCE Current)
{
	GTCX
	struct eif_ex_285 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_BOOLEAN tb1;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(325, 0x00).id);
	
	tb1 = F326_4991(RTCW(loc1), *(EIF_REFERENCE *)(Current));
	return (EIF_BOOLEAN) tb1;
}

/* {IRON_PACKAGE_FILE}.add_project */
void F332_5030 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc3);
	RTLR(4,loc2);
	RTLR(5,tr2);
	RTLR(6,arg1);
	RTLR(7,arg2);
	RTLIU(8);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {1475,0xFFF9,2,1971,2164,2173,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNSMART(typres0.id);
		}
		F1476_14446(RTCW(tr1), ((EIF_INTEGER_32) 1L));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	}
	loc3 = F1476_14459(RTCW(loc1));
	for (;;) {
		{
			/* INLINED CODE (after) */
			tb1 = (EIF_BOOLEAN)  0;
			ti4_1 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_);
			ti4_2 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_1_);
			tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
			/* END INLINED CODE */
		}
		tb1 = tb1;
		if (tb1) break;
		if ((EIF_BOOLEAN)(loc2 != NULL)) break;
		{
			/* INLINED CODE (item) */
			tr1 = (EIF_REFERENCE)  0;
			tr2 = *(EIF_REFERENCE *)(loc3);
			tr1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_REFERENCE *)RTCW(tr2) + (*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		loc2 = tr1;
		tb2 = '\0';
		tr1 = eif_boxed_item(loc2,1);
		tb3 = F2165_21118(RTCW(arg1), tr1);
		if (tb3) {
			tr1 = eif_boxed_item(loc2,2);
			tb3 = F2165_21118(RTCW(arg2), tr1);
			tb2 = tb3;
		}
		if (tb2) {
		} else {
			loc2 = (EIF_REFERENCE) NULL;
		}
		{
			/* INLINED CODE (forth) */
			(*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_))++;
			/* END INLINED CODE */
		}
		;
	}
	if ((EIF_BOOLEAN)(loc2 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,1971,2173,2173,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNTS(typres0.id, 3, 0);
		}
		((EIF_TYPED_VALUE *)tr1+1)->it_r = arg1;
		RTAR(tr1,arg1);
		((EIF_TYPED_VALUE *)tr1+2)->it_r = arg2;
		RTAR(tr1,arg2);
		loc2 = (EIF_REFERENCE) tr1;
		F1476_14485(RTCW(loc1), loc2);
	} else {
		
		eif_put_reference_item(RTCW(loc2),1,arg1);
		
		eif_put_reference_item(RTCW(loc2),2,arg2);
	}
	RTLE;
}

/* {IRON_PACKAGE_FILE}.add_setup */
void F332_5032 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc3);
	RTLR(4,loc2);
	RTLR(5,tr2);
	RTLR(6,arg1);
	RTLR(7,arg2);
	RTLIU(8);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {1475,0xFFF9,2,1971,2164,2173,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNSMART(typres0.id);
		}
		F1476_14446(RTCW(tr1), ((EIF_INTEGER_32) 1L));
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) loc1;
	}
	loc3 = F1476_14459(RTCW(loc1));
	for (;;) {
		{
			/* INLINED CODE (after) */
			tb1 = (EIF_BOOLEAN)  0;
			ti4_1 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_);
			ti4_2 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_1_);
			tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
			/* END INLINED CODE */
		}
		tb1 = tb1;
		if (tb1) break;
		if ((EIF_BOOLEAN)(loc2 != NULL)) break;
		{
			/* INLINED CODE (item) */
			tr1 = (EIF_REFERENCE)  0;
			tr2 = *(EIF_REFERENCE *)(loc3);
			tr1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_REFERENCE *)RTCW(tr2) + (*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		loc2 = tr1;
		tb2 = '\0';
		tr1 = eif_boxed_item(loc2,1);
		tb3 = F2165_21118(RTCW(arg1), tr1);
		if (tb3) {
			tr1 = eif_boxed_item(loc2,2);
			tb3 = F2174_21423(RTCW(arg2), tr1);
			tb2 = tb3;
		}
		if (tb2) {
		} else {
			loc2 = (EIF_REFERENCE) NULL;
		}
		{
			/* INLINED CODE (forth) */
			(*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_))++;
			/* END INLINED CODE */
		}
		;
	}
	if ((EIF_BOOLEAN)(loc2 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,1971,2164,2173,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNTS(typres0.id, 3, 0);
		}
		((EIF_TYPED_VALUE *)tr1+1)->it_r = arg1;
		RTAR(tr1,arg1);
		((EIF_TYPED_VALUE *)tr1+2)->it_r = arg2;
		RTAR(tr1,arg2);
		loc2 = (EIF_REFERENCE) tr1;
		F1476_14485(RTCW(loc1), loc2);
	} else {
		
		eif_put_reference_item(RTCW(loc2),1,arg1);
		
		eif_put_reference_item(RTCW(loc2),2,arg2);
	}
	RTLE;
}

void EIF_Minit291 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/ir291.c <==
/*
 * Code for class IRON_PACKAGE_FILE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ir291.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {IRON_PACKAGE_FILE}.exists */
EIF_BOOLEAN F331_5021 (EIF_REFERENCE Current)
{
	GTCX
	struct eif_ex_281 sloc1;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
	EIF_BOOLEAN tb1;
	
	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_0_0_0_0_);
	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
	RT_DFS(&sloc1.overhead, eif_new_type(320, 0x00).id);
	
	tb1 = F321_4940(RTCW(loc1), *(EIF_REFERENCE *)(Current));
	return (EIF_BOOLEAN) tb1;
}

/* {IRON_PACKAGE_FILE}.add_project */
void F331_5031 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,loc3);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLR(5,tr2);
	RTLR(6,arg1);
	RTLR(7,arg2);
	RTLIU(8);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {1522,0xFFF9,2,2017,2212,2219,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc1 = RTLNSMART(typres0.id);
		}
		F1523_14940(RTCW(loc1), ((EIF_INTEGER_32) 1L));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
	}
	tr1 = F1523_14954(RTCW(loc1));
	loc3 = (EIF_REFERENCE) tr1;
	for (;;) {
		{
			/* INLINED CODE (GENERAL_SPECIAL_ITERATION_CURSOR.after) */
			tb1 = (EIF_BOOLEAN)  0;
			ti4_1 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_);
			ti4_2 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_1_);
			tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
			/* END INLINED CODE */
		}
		tb1 = tb1;
		if (tb1) break;
		if ((EIF_BOOLEAN)(loc2 != NULL)) break;
		{
			/* INLINED CODE (GENERAL_SPECIAL_ITERATION_CURSOR.item) */
			tr1 = (EIF_REFERENCE)  0;
			tr2 = *(EIF_REFERENCE *)(loc3);
			tr1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_REFERENCE *)RTCW(tr2) + (*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		loc2 = tr1;
		tb2 = '\0';
		tr1 = eif_boxed_item(loc2,1);
		tb3 = F2213_21581(RTCW(arg1), tr1);
		if (tb3) {
			tr1 = eif_boxed_item(loc2,2);
			tb3 = F2213_21581(RTCW(arg2), tr1);
			tb2 = tb3;
		}
		if (tb2) {
		} else {
			loc2 = (EIF_REFERENCE) NULL;
		}
		{
			/* INLINED CODE (GENERAL_SPECIAL_ITERATION_CURSOR.forth) */
			(*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_))++;
			/* END INLINED CODE */
		}
		;
	}
	if ((EIF_BOOLEAN)(loc2 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,2017,2219,2219,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNTS(typres0.id, 3, 0);
		}
		((EIF_TYPED_VALUE *)tr1+1)->it_r = arg1;
		RTAR(tr1,arg1);
		((EIF_TYPED_VALUE *)tr1+2)->it_r = arg2;
		RTAR(tr1,arg2);
		loc2 = (EIF_REFERENCE) tr1;
		F1523_14980(RTCW(loc1), loc2);
	} else {
		
		eif_put_reference_item(RTCW(loc2),1,arg1);
		
		eif_put_reference_item(RTCW(loc2),2,arg2);
	}
	RTLE;
}

/* {IRON_PACKAGE_FILE}.add_setup */
void F331_5033 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	RTCFDT;
	RTLD;
	
	RTLI(8);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,loc3);
	RTLR(3,tr1);
	RTLR(4,loc2);
	RTLR(5,tr2);
	RTLR(6,arg1);
	RTLR(7,arg2);
	RTLIU(8);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {1522,0xFFF9,2,2017,2212,2219,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc1 = RTLNSMART(typres0.id);
		}
		F1523_14940(RTCW(loc1), ((EIF_INTEGER_32) 1L));
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) loc1;
	}
	tr1 = F1523_14954(RTCW(loc1));
	loc3 = (EIF_REFERENCE) tr1;
	for (;;) {
		{
			/* INLINED CODE (GENERAL_SPECIAL_ITERATION_CURSOR.after) */
			tb1 = (EIF_BOOLEAN)  0;
			ti4_1 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_);
			ti4_2 = *(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_1_);
			tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
			/* END INLINED CODE */
		}
		tb1 = tb1;
		if (tb1) break;
		if ((EIF_BOOLEAN)(loc2 != NULL)) break;
		{
			/* INLINED CODE (GENERAL_SPECIAL_ITERATION_CURSOR.item) */
			tr1 = (EIF_REFERENCE)  0;
			tr2 = *(EIF_REFERENCE *)(loc3);
			tr1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_REFERENCE *)RTCW(tr2) + (*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_)))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		loc2 = tr1;
		tb2 = '\0';
		tr1 = eif_boxed_item(loc2,1);
		tb3 = F2213_21581(RTCW(arg1), tr1);
		if (tb3) {
			tr1 = eif_boxed_item(loc2,2);
			tb3 = F2220_21856(RTCW(arg2), tr1);
			tb2 = tb3;
		}
		if (tb2) {
		} else {
			loc2 = (EIF_REFERENCE) NULL;
		}
		{
			/* INLINED CODE (GENERAL_SPECIAL_ITERATION_CURSOR.forth) */
			(*(EIF_INTEGER_32 *)(loc3+ _LNGOFF_2_0_0_0_))++;
			/* END INLINED CODE */
		}
		;
	}
	if ((EIF_BOOLEAN)(loc2 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFFF9,2,2017,2212,2219,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNTS(typres0.id, 3, 0);
		}
		((EIF_TYPED_VALUE *)tr1+1)->it_r = arg1;
		RTAR(tr1,arg1);
		((EIF_TYPED_VALUE *)tr1+2)->it_r = arg2;
		RTAR(tr1,arg2);
		loc2 = (EIF_REFERENCE) tr1;
		F1523_14980(RTCW(loc1), loc2);
	} else {
		
		eif_put_reference_item(RTCW(loc2),1,arg1);
		
		eif_put_reference_item(RTCW(loc2),2,arg2);
	}
	RTLE;
}

void EIF_Minit291 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
